@@ -36,7 +36,8 @@ class ApmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateApmInstance", params)
+            headers = request.headers
+            body = self.call("CreateApmInstance", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateApmInstanceResponse()
@@ -64,7 +65,8 @@ class ApmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeApmAgent", params)
+            headers = request.headers
+            body = self.call("DescribeApmAgent", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeApmAgentResponse()
@@ -92,7 +94,8 @@ class ApmClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeApmInstances", params)
+            headers = request.headers
+            body = self.call("DescribeApmInstances", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeApmInstancesResponse()
@@ -103,6 +106,64 @@ class ApmClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeMetricRecords(self, request):
+        """拉取通用指标列表
+
+        :param request: Request instance for DescribeMetricRecords.
+        :type request: :class:`tencentcloud.apm.v20210622.models.DescribeMetricRecordsRequest`
+        :rtype: :class:`tencentcloud.apm.v20210622.models.DescribeMetricRecordsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeMetricRecords", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeMetricRecordsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeServiceOverview(self, request):
+        """服务概览数据拉取
+
+        :param request: Request instance for DescribeServiceOverview.
+        :type request: :class:`tencentcloud.apm.v20210622.models.DescribeServiceOverviewRequest`
+        :rtype: :class:`tencentcloud.apm.v20210622.models.DescribeServiceOverviewResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeServiceOverview", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeServiceOverviewResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
